#include "DisplayProcesser.h"


Color::Color() {
  red = 0;
  green = 0;
  blue = 0;
  white = 0;
}

Color::Color(int redInit, int greenInit, int blueInit, int whiteInit) {
  red = redInit;
  green = greenInit;
  blue = blueInit;
  white = whiteInit;
}

ColorTheme::ColorTheme() {}

DisplayProcessor::DisplayProcessor() {
  this->hourLEDs = new Adafruit_NeoPixel(nPixH, pinHLED, NEO_GRB + NEO_KHZ800);  
  this->minuteLEDs = new Adafruit_NeoPixel(nPixM, pinMLED, NEO_GRBW + NEO_KHZ800); 
  
  //initialize theme colors
  theme.secondColor.red = 0;
  theme.secondColor.green = 0;
  theme.secondColor.blue = 0;
  theme.secondColor.white = 0;
  
  theme.minuteCenterColor.red = 0;
  theme.minuteCenterColor.green = 0;
  theme.minuteCenterColor.blue = 0;
  theme.minuteCenterColor.white = 0;

  theme.minuteSecondaryColor.red = 0;
  theme.minuteSecondaryColor.green = 0;
  theme.minuteSecondaryColor.blue = 255;
  theme.minuteSecondaryColor.white = 0;
    
  theme.minuteBackgroundColor.red = 0;
  theme.minuteBackgroundColor.green = 255;
  theme.minuteBackgroundColor.blue = 0;
  theme.minuteBackgroundColor.white = 0;
  
  theme.hourBackgroundColor.red = 0;
  theme.hourBackgroundColor.green = 10;
  theme.hourBackgroundColor.blue = 10;
  
  theme.hourColor.red = 30;
  theme.hourColor.green = 0;
  theme.hourColor.blue = 0;
  
  //start LED strip
  hourLEDs->begin();
  minuteLEDs->begin();
}

void DisplayProcessor::toggleLightMode() {
  
  
}
void DisplayProcessor::toggleDimmingMode() {
  
}

void DisplayProcessor::updateFrontDial(int hour) {
  //set all leds to background color
  for (int i = 0; i < nPixH; i++) {
    hourLEDs->setPixelColor(i, theme.hourBackgroundColor.red, theme.hourBackgroundColor.green, theme.hourBackgroundColor.blue);
  }

  //set the hour led

  hourLEDs->setPixelColor((hour%12)*3, theme.hourColor.red, theme.hourColor.green, theme.hourColor.blue);
  hourLEDs->setPixelColor((hour%12)*3 + 1, theme.hourColor.red, theme.hourColor.green, theme.hourColor.blue);
  hourLEDs->setPixelColor((hour%12)*3 + 2, theme.hourColor.red, theme.hourColor.green, theme.hourColor.blue);

  //display all data in the buffer
  hourLEDs->show();
}

void DisplayProcessor::updateBackDial(int minute, int second) {
  //set all leds to background color
  for (int i = 0; i < nPixM; i++) {
    minuteLEDs->setPixelColor(i, theme.minuteBackgroundColor.red, theme.minuteBackgroundColor.green, theme.minuteBackgroundColor.blue, theme.minuteBackgroundColor.white);
  }
  
  //set the center minute leds
  minuteLEDs->setPixelColor(mapToBackDial(minute), theme.minuteCenterColor.red, theme.minuteCenterColor.green, theme.minuteCenterColor.blue, theme.minuteCenterColor.white);


  //set the second led
  minuteLEDs->setPixelColor(mapToBackDial(second), theme.secondColor.red, theme.secondColor.green, theme.secondColor.blue, theme.secondColor.white);

  if(minute > second) {
    for (int i = mapToBackDial(second); i < mapToBackDial(minute); i++) {
      minuteLEDs->setPixelColor(i%nPixM, theme.minuteSecondaryColor.red, theme.minuteSecondaryColor.green, theme.minuteSecondaryColor.blue, theme.minuteSecondaryColor.white);
    }
  }
  else if(minute < second) {
    for (int i = mapToBackDial(minute); i < mapToBackDial(second); i++) {
      minuteLEDs->setPixelColor(i%nPixM, theme.minuteSecondaryColor.red, theme.minuteSecondaryColor.green, theme.minuteSecondaryColor.blue, theme.minuteSecondaryColor.white);
    }
  }

  //display all data in the buffer
  minuteLEDs->show();
  Serial.print("current minute led: ");Serial.println(mapToBackDial(minute));
}


void DisplayProcessor::buttonPressBlink() {
  
}

int DisplayProcessor::mapToBackDial(int startMinute) {
  float mappingFactor = (nPixM/60.0);
  int ledNumber = (startMinute)*mappingFactor;
  return ledNumber;
}


