#include "Globals.h"
#include <Wire.h>

bool toggleSpeed = false;

void setup() {
  
  //setup I2C communication
  Wire.begin(); // Clock Address
  
  //setup Serial Communication
  Serial.begin(57600);

  //display the firmware version 
  Serial.println(FIRMWARE_VERSION);

  //fetch the current Time
  rtc.updateTime();

}

void loop() {
  //check for button presses
  if(buttonDriver.minuteUpPressed()){
    Serial.println("Min Up Button Pressed");
    int currentMinute = rtc.getMinute();
    if(currentMinute == 59)
      currentMinute = 0;
    else
      currentMinute++;
    rtc.setMinute(currentMinute);
    rtc.updateTime();
  }
  
  if(buttonDriver.hourUpPressed()) {
    Serial.println("Hour Up Button Pressed");
    int currentHour = rtc.getHour();
    if(currentHour == 23)
      currentHour = 0;
    else
      currentHour++;
    rtc.setHour(currentHour);
    rtc.updateTime();
  }
  
  if(buttonDriver.secondResetPressed()) {
    Serial.println("Second Reset Button Pressed");
    rtc.resetSecond();
    rtc.updateTime();
  }
  
  if(buttonDriver.lightModePressed()) {
    displayProcessor.toggleLightMode();
    Serial.println("Light Mode Button Pressed");
  }
  
  if(buttonDriver.dimmingModePressed()) {
    displayProcessor.toggleDimmingMode();
    Serial.println("Dimming Mode Button Pressed");
  }

  //Process incoming serial commands
  if(Serial.available()) {
    int data = Serial.read();
    if(data == 's') {
      rtc.resetSecond();
    }
    if(data == 'f') {
      rtc.updateTime();
    }
    if(data == 'm') {
      rtc.setMinute(13);
    }
  }
  
  //fetch the current time from rtc every 1/2 second
  if (millis() - previousFetchTime > fetchTimeIntervol) {
    //get the updated time from the realtime clock
    rtc.updateTime();

    //update the led strip
    displayProcessor.updateBackDial(rtc.getMinute(), rtc.getSecond());
    displayProcessor.updateFrontDial(rtc.getHour());

    //reset the time of update
    previousFetchTime = millis();
  }

  //set the motor speed
  motorController.setSpeed(30, HIGH);
  
}

