#include "rtc.h"

RTC::RTC() {
  rtc_address = 0x68;
	currentSecond = 0;
	currentMinute = 0;
	currentHour = 0;
	secondRegister = 0x00;
	minuteRegister = 0x01;
	hourRegister = 0x02;
	dayRegister = 0x03;
	dateRegister = 0x04;
	monthRegister = 0x05;
	yearRegister = 0x06;
	controlRegister = 0x07;
}

void RTC::updateTime() {
  //Get the time content from the rtc through I2C
  Wire.beginTransmission(rtc_address);
  Wire.write(secondRegister);
  Wire.endTransmission();
  Wire.requestFrom(rtc_address, 3);
  int secondRegisterContent = Wire.read();
  int minuteRegisterContent = Wire.read();
  int hourRegisterContent = Wire.read();
  
  //convert content in second register to seconds
  int secondLower = secondRegisterContent & 0x0F;
  int secondHigher = (secondRegisterContent & 0x70) >> 4;
  currentSecond = secondLower + secondHigher*10;

  //convert content in minute register to minutes
  int minuteLower = minuteRegisterContent & 0x0F;
  int minuteHigher = (minuteRegisterContent & 0x70) >> 4;
  currentMinute = minuteLower + minuteHigher*10;

  //convert content in hour register to hours
  int hourLower = hourRegisterContent & 0x0F;
  int hourHigher = (hourRegisterContent & 0x030) >> 4;
  currentHour = hourLower + hourHigher*10;

  //print the current time to serial 
  Serial.print("Current Time: ");
  Serial.print(currentHour);Serial.print(":");
  Serial.print(currentMinute);Serial.print(":");
  Serial.println(currentSecond);
  Serial.println(" ");
}

int RTC::getSecond(){
  return currentSecond;
}

int RTC::getMinute(){
  return currentMinute;
}

int RTC::getHour(){
  return currentHour;
}

void RTC::resetSecond(){
  //set the second register of the rtc to zero
	Wire.beginTransmission(rtc_address);
  Wire.write(secondRegister);
  Wire.write(0x00);
  Wire.endTransmission();

  //send status message to serial
  Serial.println("Setting Current Second Time to Zero");
}

void RTC::setMinute(int minute){
  //clip the maximum value to 59
  if(minute > 59) {
    minute = 59;
  }
  
  //convert from integer to binary format
	int minuteTens = int(minute/10);
  int minuteOnes = minute - minuteTens*10;
  int minuteRegisterContent = minuteOnes + (minuteTens << 4);

  //write content to rtc
  Wire.beginTransmission(rtc_address);
  Wire.write(minuteRegister);
  Wire.write(minuteRegisterContent);
  Wire.endTransmission();

  //send status message to serial
  Serial.print("Setting Minute to: ");Serial.println(minute);
}

void RTC::setHour(int hour){
  //clip the maximum value to 23
  if(hour > 23) {
    hour = 23;
  }
  
  //convert from integer to binary format
  int hourTens = int(hour/10);
  int hourOnes = hour - hourTens*10;
  int hourRegisterContent = hourOnes + (hourTens << 4);

  //write content to rtc
  Wire.beginTransmission(rtc_address);
  Wire.write(hourRegister);
  Wire.write(hourRegisterContent);
  Wire.endTransmission();

  //send status message to serial
  Serial.print("Setting Hour to: ");Serial.println(hour);
}
